@@ -112,8 +112,6 @@ CREATE TABLE IF NOT EXISTS DhtOp (
     receipts_complete   INTEGER     NULL,     -- BOOLEAN
     last_publish_time   INTEGER     NULL,   -- UNIX TIMESTAMP SECONDS
 
-    blob             BLOB           NOT NULL,
-
     -- 0: Awaiting System Validation Dependencies.
     -- 1: Successfully System Validated (And ready for app validation).
     -- 2: Awaiting App Validation Dependencies.
@@ -140,7 +138,9 @@ CREATE TABLE IF NOT EXISTS DhtOp (
     FOREIGN KEY(header_hash) REFERENCES Header(hash) ON DELETE CASCADE
 );
 CREATE INDEX IF NOT EXISTS DhtOp_type_dep_idx ON DhtOp ( type, dependency );
+CREATE INDEX IF NOT EXISTS DhtOp_type_when_int_idx ON DhtOp ( type, when_integrated );
 CREATE INDEX IF NOT EXISTS DhtOp_validation_stage_idx ON DhtOp ( validation_stage, type, dependency );
+CREATE INDEX IF NOT EXISTS DhtOp_stage_type_status_idx ON DhtOp ( validation_stage, type, validation_status);
 CREATE INDEX IF NOT EXISTS DhtOp_validation_status_idx ON DhtOp ( validation_status );
 CREATE INDEX IF NOT EXISTS DhtOp_authored_timestamp_idx ON DhtOp ( authored_timestamp );
 CREATE INDEX IF NOT EXISTS DhtOp_storage_center_loc_idx ON DhtOp ( storage_center_loc );
